"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const child_process_1 = require("child_process");
const base = path.resolve(__dirname, '..', 'bin');
exports.ADB_BINARY_FILE = {
    win32: path.resolve(base, 'window/adb.exe'),
    darwin: path.resolve(base, 'mac/adb'),
    linux: path.resolve(base, 'linux/adb'),
};
function isSystemAdbAvailable() {
    let systemAdbExist = false;
    try {
        const output = child_process_1.execSync('adb --version');
        const result = output.toString();
        if (result.toLowerCase().includes('version')) {
            systemAdbExist = true;
        }
    }
    catch (e) {
        systemAdbExist = false;
    }
    return systemAdbExist;
}
exports.isSystemAdbAvailable = isSystemAdbAvailable;
function execADBCommand(command, option) {
    let execCmd = command;
    if (!isSystemAdbAvailable()) {
        let cmd = command.split(' ');
        const binFile = exports.ADB_BINARY_FILE[process.platform];
        cmd[0] = `"${binFile}"`;
        execCmd = cmd.join(' ');
    }
    return new Promise((resolve, reject) => {
        child_process_1.exec(execCmd, option || { stdio: 'inherit' }, (err, stdout, stderr) => {
            console.log(err, stdout, stderr);
            if (err) {
                reject(err);
            }
            resolve(stdout);
        });
    }).catch(err => {
        return err;
    });
}
exports.execADBCommand = execADBCommand;
//# sourceMappingURL=AdbDriver.js.map